@@ -1,20 +1,20 @@
 """Module containing the logic for connector adaptor"""
 
-from subprocess import getstatusoutput
 import re
 
 from dgspoc.exceptions import AdaptorAuthenticationError
 
 from dgspoc.constant import ECODE
 
+from dgspoc.utils import MiscOutput
+
 
 class Adaptor:
     def __init__(self, adaptor, *args, **kwargs):
         self.adaptor = adaptor.strip()
         if self.is_unreal_device_adaptor:
             addr = args[0]
-            testcase = kwargs.get('testcase', '')
-            self.device = UnrealDeviceAdaptor(addr, testcase=testcase)
+            self.device = UnrealDeviceAdaptor(addr)
         else:
             fmt = '*** Need to implement "{}" adaptor'
             NotImplementedError(fmt.format(adaptor))
@@ -53,10 +53,9 @@ class Adaptor:
 
 
 class UnrealDeviceAdaptor:
-    def __init__(self, address, testcase=''):
+    def __init__(self, address):
         self.address = str(address).strip()
         self.name = self.address
-        self.testcase = str(testcase).strip()
         self.result = ''
         self.exit_code = ECODE.SUCCESS
 
@@ -65,16 +64,14 @@ class UnrealDeviceAdaptor:
         return True if self.exit_code == ECODE.SUCCESS else False
 
     def process(self, statement):
-        self.exit_code, self.result = getstatusoutput(statement.strip())
+        result = MiscOutput.execute_shell_command(statement.strip())
+        self.exit_code, self.result = result.exit_code, result.output
         print(self.result)
         return self.status
 
     def connect(self):
         fmt = 'unreal-device connect --host={}'
         unreal_statement = fmt.format(self.address)
-        if self.testcase:
-            fmt = '{} --testcase={}'
-            unreal_statement = fmt.format(unreal_statement, self.testcase)
         self.process(unreal_statement)
         return self.status
 
@@ -105,9 +102,6 @@ class UnrealDeviceAdaptor:
         addr = kwargs.get('name', self.address)
         fmt = 'unreal-device reload --host={}'
         unreal_statement = fmt.format(addr)
-        if self.testcase:
-            fmt = '{} --testcase={}'
-            unreal_statement = fmt.format(unreal_statement, self.testcase)
         self.process(unreal_statement)
         return self.status
 
