@@ -14,7 +14,7 @@ import robot
 from dgspoc.utils import File
 from dgspoc.utils import Misc
 
-__version__ = '0.3.2'
+__version__ = '0.3.4'
 version = __version__
 
 __all__ = [
@@ -25,6 +25,11 @@ __all__ = [
 
 class Data:
 
+    console_cli_name = 'dgs'
+    console_cli_fullname = 'describe-get-system'
+    console_supported_commands = ['build', 'info', 'run', 'search',
+                                  'test', 'version', 'usage']
+
     # app yaml files
     app_directory = File.get_path('.geekstrident', 'dgspoc', is_home=True)
     template_storage_filename = File.get_path(app_directory, 'template_storage.yaml')
