@@ -4,7 +4,8 @@ user describing problem"""
 
 import re
 import operator
-import yaml
+# import yaml
+from datetime import datetime
 
 from textwrap import indent
 from textwrap import dedent
@@ -49,7 +50,7 @@ class ScriptInfo(DotObject):
     def disable_testing(self):
         self._enabled_testing = False
 
-    def get_class_name(self):
+    def get_class_name(self):   # noqa
         return 'TestClass'
 
     def reset_devices_vars(self):
@@ -1474,7 +1475,8 @@ class VerificationStatement(Statement):
                     lst.append(stmt)
 
                 lst.append('${total_count}=  get length   ${result}')
-                lst.append('should be true   ${total_count} == %s' % result.expected_condition)
+                fmt = 'should be true   ${total_count} %s %s'
+                lst.append(fmt % (result.condition_symbol, result.expected_condition))
 
         else:
             for device_name in self.result.devices_names:
@@ -1503,10 +1505,11 @@ class VerificationStatement(Statement):
 
                 lst.append('total_count = len(result)')
                 if self.is_unittest and self.is_ancestor_section_statement:
-                    fmt = 'self.assertTrue(total_count == %s)'
-                    lst.append(fmt % result.expected_condition)
+                    fmt = 'self.assertTrue(total_count %s %s)'
+                    lst.append(fmt % (result.condition_symbol, result.expected_condition))
                 else:
-                    lst.append('assert total_count == %s' % result.expected_condition)
+                    fmt = 'assert total_count %s %s'
+                    lst.append(fmt % (result.condition_symbol, result.expected_condition))
 
         stmt = self.indent_data('\n'.join(lst), self.level)
         return stmt
@@ -1701,12 +1704,12 @@ class ScriptBuilder:
         user_fmt = '# Created by  : {0.username}'
         email_fmt = '# Email       : {0.email}'
         company_fmt = '# Company     : {0.company}'
-        date_fmt = '# Created date: {}'
+        datetime_str = '# Created date: {:%Y-%m-%d}'.format(datetime.now())
         lst = [fmt.format(self.framework.lower())]
         self.username and lst.append(user_fmt.format(self))
         self.email and lst.append(email_fmt.format(self))
         self.company and lst.append(company_fmt.format(self))
-        not SCRIPTINFO.is_testing_enabled and lst.append(date_fmt)
+        not SCRIPTINFO.is_testing_enabled and lst.append(datetime_str)
 
         intro = '\n'.join(['#' * 80] + lst + ['#' * 80])
         return intro
